package sun.awt.macos;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Event;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ComponentPeer;

public abstract class MComponentPeer implements ComponentPeer {
   Component target;
   int pData;
   int pInternationalData;
   int mOwnerPane;
   int mFont;
   int mSize;
   int mStyle;
   Color mForeColor;
   Color mBackColor;
   boolean mRecalculateClip;
   boolean mIsContainer;
   boolean mIsButton;
   boolean mIsChoice;
   boolean mIsResizableFrame;
   int mObscuredRgn;
   int mClipRgn;

   MComponentPeer(Component var1) {
      this.target = var1;
      Container var2 = var1.getParent();
      this.setup();
      this.create((MComponentPeer)(var2 != null ? ((Component)var2).getPeer() : null));
      this.initialize();
   }

   abstract void create(MComponentPeer var1);

   void create(MComponentPeer var1, Object var2) {
      this.create(var1);
   }

   void setup() {
      this.mForeColor = new Color(0, 0, 0);
      this.mBackColor = new Color(192, 192, 192);
      this.pSetup();
   }

   void initialize() {
      Rectangle var1 = this.target.bounds();
      this.reshape(var1.x, var1.y, var1.width, var1.height);
      if (this.target.isVisible()) {
         this.show();
      } else {
         this.hide();
      }

      Color var2;
      if ((var2 = this.target.getForeground()) != null) {
         this.setForeground(var2);
      }

      if ((var2 = this.target.getBackground()) != null) {
         this.setBackground(var2);
      }

      Font var3;
      if ((var3 = this.target.getFont()) != null) {
         this.setFont(var3);
      }

   }

   public void dispose() {
      this.pDispose();
   }

   public ColorModel getColorModel() {
      return MToolkit.getStaticColorModel();
   }

   public Toolkit getToolkit() {
      return Toolkit.getDefaultToolkit();
   }

   public Graphics getGraphics() {
      MacGraphics var1 = new MacGraphics(this);
      ((Graphics)var1).setColor(this.target.getForeground());
      ((Graphics)var1).setFont(this.target.getFont());
      return var1;
   }

   public FontMetrics getFontMetrics(Font var1) {
      return MacFontMetrics.getFontMetrics(var1);
   }

   public void show() {
      this.pShow();
   }

   public void hide() {
      this.pHide();
   }

   public void enable() {
      this.pEnable();
   }

   public void disable() {
      this.pDisable();
   }

   public void paint(Graphics var1) {
      var1.setColor(this.target.getForeground());
      var1.setFont(this.target.getFont());
      this.target.paint(var1);
   }

   public void repaint(long var1, int var3, int var4, int var5, int var6) {
      this.pRepaint(var1, var3, var4, var5, var6);
   }

   public void print(Graphics var1) {
      Dimension var2 = this.target.size();
      var1.setColor(this.target.getForeground());
      var1.setFont(this.target.getFont());
      var1.drawRect(0, 0, var2.width - 1, var2.height - 1);
      this.target.print(var1);
   }

   public void reshape(int var1, int var2, int var3, int var4) {
      this.pReshape(var1, var2, var3, var4);
   }

   public native void setForeground(Color var1);

   public native void setBackground(Color var1);

   public native void setFont(Font var1);

   public native boolean handleEvent(Event var1);

   public Image createImage(ImageProducer var1) {
      return new MacImage(var1);
   }

   public Image createImage(int var1, int var2) {
      return new MacImage(var1, var2);
   }

   public boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4) {
      return MToolkit.prepareScrImage(var1, var2, var3, var4);
   }

   public int checkImage(Image var1, int var2, int var3, ImageObserver var4) {
      return MToolkit.checkScrImage(var1, var2, var3, var4);
   }

   public Dimension minimumSize() {
      return this.target.size();
   }

   public Dimension preferredSize() {
      return this.minimumSize();
   }

   public native void requestFocus();

   public native void nextFocus();

   protected void gotFocus() {
      this.target.postEvent(new Event(this.target, 1004, (Object)null));
   }

   protected void lostFocus() {
      this.target.postEvent(new Event(this.target, 1005, (Object)null));
   }

   private native void pSetup();

   private native void pShow();

   private native void pHide();

   private native void pEnable();

   private native void pDisable();

   private native void pPrint(Graphics var1);

   private native void pReshape(int var1, int var2, int var3, int var4);

   private native void pRepaint(long var1, int var3, int var4, int var5, int var6);

   private native void pDispose();

   public void finalize() {
      this.dispose();
   }

   protected void handleWindowClosing() {
      this.target.postEvent(new Event(this.target, 201, (Object)null));
   }

   void handleExpose() {
      InterfaceThread.postInterfaceEvent(1, this.target, 0, 0, 0, 0, 0L, 0, 0);
   }

   void handleRepaint(int var1, int var2, int var3, int var4) {
      InterfaceThread.postInterfaceEvent(2, this.target, var1, var2, var3, var4, 0L, 0, 0);
   }

   private int modifiersToJavaFlags(int var1) {
      int var2 = 0;
      if ((var1 & 256) != 0) {
         var2 |= 4;
      }

      if ((var1 & 512) != 0) {
         var2 |= 1;
      }

      if ((var1 & 2048) != 0) {
         var2 |= 8;
      }

      if ((var1 & 4096) != 0) {
         var2 |= 2;
      }

      return var2;
   }

   protected void handleKeyEvent(int var1, int var2, int var3, int var4, boolean var5, int var6) {
      long var7 = 0L;
      int var9 = this.modifiersToJavaFlags(var4);
      boolean var10 = true;
      var7 = System.currentTimeMillis();
      switch (var3) {
         case 1:
            var3 = 1000;
            break;
         case 4:
            var3 = 1001;
            break;
         case 11:
            var3 = 1002;
            break;
         case 12:
            var3 = 1003;
            break;
         case 28:
            var3 = 1006;
            break;
         case 29:
            var3 = 1007;
            break;
         case 30:
            var3 = 1004;
            break;
         case 31:
            var3 = 1005;
            break;
         default:
            var10 = false;
      }

      if (var10) {
         if (var5) {
            InterfaceThread.postInterfaceEvent(9, this.target, var1, var2, 0, 0, var7, var9, var3, 0, var6);
         } else {
            InterfaceThread.postInterfaceEvent(10, this.target, var1, var2, 0, 0, var7, var9, var3, 0, var6);
         }
      } else if (var5) {
         InterfaceThread.postInterfaceEvent(7, this.target, var1, var2, 0, 0, var7, var9, var3, 0, var6);
      } else {
         InterfaceThread.postInterfaceEvent(8, this.target, var1, var2, 0, 0, var7, var9, var3, 0, var6);
      }
   }

   protected void handleMouseChanged(int var1, int var2, int var3, int var4, boolean var5, int var6) {
      long var7 = System.currentTimeMillis();
      int var9 = this.modifiersToJavaFlags(var3);
      if (var5) {
         InterfaceThread.postInterfaceEvent(3, this.target, var1, var2, 0, 0, var7, var9, 0, var4, var6);
      } else {
         InterfaceThread.postInterfaceEvent(4, this.target, var1, var2, 0, 0, var7, var9, 0, var4, var6);
      }
   }

   protected void handleMouseMoved(int var1, int var2, int var3, boolean var4) {
      long var5 = System.currentTimeMillis();
      int var7 = this.modifiersToJavaFlags(var3);
      if (var4) {
         InterfaceThread.postInterfaceEvent(6, this.target, var1, var2, 0, 0, var5, var7, 0);
      } else {
         InterfaceThread.postInterfaceEvent(5, this.target, var1, var2, 0, 0, var5, var7, 0);
      }
   }

   protected void handleMouseEnter(int var1, int var2, int var3) {
      long var4 = System.currentTimeMillis();
      int var6 = this.modifiersToJavaFlags(var3);
      InterfaceThread.postInterfaceEvent(11, this.target, var1, var2, 0, 0, var4, var6, 0);
   }

   protected void handleMouseExit(int var1, int var2, int var3) {
      long var4 = System.currentTimeMillis();
      int var6 = this.modifiersToJavaFlags(var3);
      InterfaceThread.postInterfaceEvent(12, this.target, var1, var2, 0, 0, var4, var6, 0);
   }
}
