package sun.awt.macos;

import java.awt.Color;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.image.ImageObserver;
import sun.awt.image.ImageRepresentation;
import sun.awt.image.OffScreenImageSource;

public class MacGraphics extends Graphics {
   int pData;
   Color foreground;
   Font font;
   int originX;
   int originY;
   float scaleX = 1.0F;
   float scaleY = 1.0F;
   ImageRepresentation imageRepresentation;
   MComponentPeer componentPeer;

   private native void createFromComponent(MComponentPeer var1);

   private native void createFromGraphics(MacGraphics var1);

   private native void createFromIRepresentation(ImageRepresentation var1);

   private native void pSetFont(Font var1);

   private native void pSetForeground(Color var1);

   private native void pSetScaling(float var1, float var2);

   private native void pSetOrigin(int var1, int var2);

   MacGraphics(MacGraphics var1) {
      this.imageRepresentation = var1.imageRepresentation;
      this.componentPeer = var1.componentPeer;
      this.createFromGraphics(var1);
   }

   MacGraphics(MComponentPeer var1) {
      this.componentPeer = var1;
      this.createFromComponent(var1);
   }

   public MacGraphics(Image var1) {
      OffScreenImageSource var2 = (OffScreenImageSource)var1.getSource();
      this.imageRepresentation = var2.getImageRep();
      this.createFromIRepresentation(this.imageRepresentation);
      this.setFont(new Font("Dialog", 0, 9));
   }

   public Graphics create() {
      MacGraphics var1 = new MacGraphics(this);
      var1.foreground = this.foreground;
      var1.font = this.font;
      var1.originX = this.originX;
      var1.originY = this.originY;
      var1.scaleX = this.scaleX;
      var1.scaleY = this.scaleY;
      var1.imageRepresentation = this.imageRepresentation;
      return var1;
   }

   public void translate(int var1, int var2) {
      this.originX = (int)((float)this.originX + (float)var1 * this.scaleX);
      this.originY = (int)((float)this.originY + (float)var2 * this.scaleY);
      this.pSetOrigin(this.originX, this.originY);
   }

   public void scale(float var1, float var2) {
      this.scaleX *= var1;
      this.scaleY *= var2;
      this.pSetScaling(this.scaleX, this.scaleY);
   }

   public native void dispose();

   public void finalize() {
      this.dispose();
   }

   public void setFont(Font var1) {
      if (var1 != null && this.font != var1) {
         this.font = var1;
         this.pSetFont(var1);
      }

   }

   public Font getFont() {
      return this.font;
   }

   public FontMetrics getFontMetrics(Font var1) {
      return MacFontMetrics.getFontMetrics(var1);
   }

   public void setColor(Color var1) {
      if (var1 != null && var1 != this.foreground) {
         this.foreground = var1;
         this.pSetForeground(var1);
      }

   }

   public Color getColor() {
      return this.foreground;
   }

   public native void setPaintMode();

   public native void setXORMode(Color var1);

   public Rectangle getClipRect() {
      Rectangle var1 = new Rectangle();
      this.getClipRect(var1);
      return var1;
   }

   native void getClipRect(Rectangle var1);

   public native void clipRect(int var1, int var2, int var3, int var4);

   public native void clearRect(int var1, int var2, int var3, int var4);

   public native void fillRect(int var1, int var2, int var3, int var4);

   public native void drawRect(int var1, int var2, int var3, int var4);

   public native void drawString(String var1, int var2, int var3);

   public native void drawChars(char[] var1, int var2, int var3, int var4, int var5);

   public native void drawBytes(byte[] var1, int var2, int var3, int var4, int var5);

   public native int drawStringWidth(String var1, int var2, int var3);

   public native int drawCharsWidth(char[] var1, int var2, int var3, int var4, int var5);

   public native int drawBytesWidth(byte[] var1, int var2, int var3, int var4, int var5);

   public native void drawLine(int var1, int var2, int var3, int var4);

   public boolean drawImage(Image var1, int var2, int var3, ImageObserver var4) {
      ImageRepresentation var5 = ((MacImage)var1).getImageRep(-1, -1);
      return var5.drawImage(this, var2, var3, (Color)null, var4);
   }

   public boolean drawImage(Image var1, int var2, int var3, int var4, int var5, ImageObserver var6) {
      if (var4 != 0 && var5 != 0) {
         if (var4 < 0) {
            var4 = -1;
         }

         if (var5 < 0) {
            var5 = -1;
         }

         ImageRepresentation var7 = ((MacImage)var1).getImageRep(var4, var5);
         return var7.drawImage(this, var2, var3, (Color)null, var6);
      } else {
         return true;
      }
   }

   public boolean drawImage(Image var1, int var2, int var3, Color var4, ImageObserver var5) {
      MacImage var6 = (MacImage)var1;
      ImageRepresentation var7 = var6.getImageRep(-1, -1);
      return var7.drawImage(this, var2, var3, var4, var5);
   }

   public boolean drawImage(Image var1, int var2, int var3, int var4, int var5, Color var6, ImageObserver var7) {
      if (var4 != 0 && var5 != 0) {
         MacImage var8 = (MacImage)var1;
         if (var4 < 0) {
            var4 = -1;
         }

         if (var5 < 0) {
            var5 = -1;
         }

         ImageRepresentation var9 = var8.getImageRep(var4, var5);
         return var9.drawImage(this, var2, var3, var6, var7);
      } else {
         return true;
      }
   }

   public native void copyArea(int var1, int var2, int var3, int var4, int var5, int var6);

   public native void drawRoundRect(int var1, int var2, int var3, int var4, int var5, int var6);

   public native void fillRoundRect(int var1, int var2, int var3, int var4, int var5, int var6);

   public native void drawPolygon(int[] var1, int[] var2, int var3);

   public native void fillPolygon(int[] var1, int[] var2, int var3);

   public native void drawOval(int var1, int var2, int var3, int var4);

   public native void fillOval(int var1, int var2, int var3, int var4);

   public native void drawArc(int var1, int var2, int var3, int var4, int var5, int var6);

   public native void fillArc(int var1, int var2, int var3, int var4, int var5, int var6);

   public String toString() {
      return this.getClass().getName() + "[" + this.originX + "," + this.originY + "," + this.scaleX + "," + this.scaleY + "]";
   }
}
